@@ -13,18 +13,18 @@
 
 from pymtl3.datatypes import *
 from pymtl3.dsl import *
-from pymtl3.passes import TracingConfigs
-from pymtl3.passes.PassGroups import SimulationPass
+from pymtl3.passes.PassGroups import DefaultPassGroup
+
+from ..VcdGenerationPass import VcdGenerationPass
 
 
 def run_test( dut, tv, tv_in, tv_out ):
   vcd_file_name = dut.__class__.__name__ + "_funky"
-  dut.config_tracing = TracingConfigs( tracing='vcd', vcd_file_name=vcd_file_name )
-  dut.elaborate()
-  dut.apply( SimulationPass() )
+  dut.set_metadata( VcdGenerationPass.vcd_file_name, vcd_file_name )
+  dut.apply( DefaultPassGroup() )
   for v in tv:
     tv_in( dut, v )
-    dut.tick()
+    dut.sim_tick()
     tv_out( dut, v )
   with open(vcd_file_name+".vcd") as fd:
     file_str = ''.join( fd.readlines() )
@@ -41,12 +41,12 @@ def test_vector_signals():
       s.in1 = InPort( Bits32 )
       s.out = OutPort( Bits32 )
 
-      @s.update
+      @update
       def add_upblk():
-        s.out = s.in0 + s.in1
+        s.out @= s.in0 + s.in1
   def tv_in( m, tv ):
-    m.in0 = tv[0]
-    m.in1 = tv[1]
+    m.in0 @= tv[0]
+    m.in1 @= tv[1]
   def tv_out( m, tv ):
     assert m.out == tv[2]
 
@@ -73,19 +73,19 @@ def test_bitstruct_signals():
       s.in1 = InPort( Bits32 )
       s.out = OutPort( Bits32 )
 
-      @s.update
+      @update
       def add_upblk():
-        s.out = s.in0.bar + s.in1
+        s.out @= s.in0.bar + s.in1
   def tv_in( m, tv ):
-    m.in0 = tv[0]
-    m.in1 = tv[1]
+    m.in0 @= tv[0]
+    m.in1 @= tv[1]
   def tv_out( m, tv ):
     assert m.out == tv[2]
 
   run_test( A2(), [
     #     in0                 in1      out
-    [  bs(b1(0), b32(0)), b32(-1), b32(-1), ],
-    [  bs(b1(0), b32(1)),  b32(1),  b32(2), ],
-    [ bs(b1(0), b32(-1)),  b32(0), b32(-1), ],
-    [ bs(b1(0), b32(42)), b32(42), b32(84), ],
+    [  bs(0, 0),  b32(-1), b32(-1), ],
+    [  bs(0, 1),  b32(1),  b32(2), ],
+    [  bs(0, -1), b32(0), b32(-1), ],
+    [  bs(0, 42), b32(42), b32(84), ],
   ], tv_in, tv_out )
